# ctyped-ffi

### ctypes wrapper for typed ffi
<br>

Wrapper around ctypes for creating typed foreign function interfaces built upon libraries

You can find support in the [IEW Discord server](https://discord.gg/qxTxVJGtst).
<br><br>
## How to install

Install `ctypedffi` with the following command:

```sh
$ pip install ctypedffi
```

Or if you want the latest git version, install it with this command:

```sh
$ pip install git+https://github.com/Setsugennoao/ctyped-ffi.git
```
